@@ -30,10 +30,11 @@
 #include <tango/tango.h>
 #include <tango/client/eventconsumer.h>
 
-#include <time.h>
-#include <signal.h>
+#include <ctime>
+#include <csignal>
 
 #include <algorithm>
+#include <memory>
 
 using namespace CORBA;
 
@@ -47,14 +48,14 @@ namespace Tango
 //-----------------------------------------------------------------------------
 
 AttributeProxy::AttributeProxy(std::string &name) :
-    dev_proxy(NULL),
+    dev_proxy(nullptr),
     ext(new AttributeProxyExt(name))
 {
     real_constructor(name);
 }
 
 AttributeProxy::AttributeProxy(const char *na) :
-    dev_proxy(NULL),
+    dev_proxy(nullptr),
     ext(new AttributeProxyExt(na))
 {
     std::string name(na);
@@ -68,23 +69,22 @@ void AttributeProxy::real_constructor(std::string &name)
     //
 
     parse_name(name);
-    std::string corba_name;
 
     //
     // Create the associated DeviceProxy object
     //
 
-    if(dbase_used == true)
+    if(dbase_used)
     {
-        if(from_env_var == true)
+        if(from_env_var)
         {
             ApiUtil *ui = ApiUtil::instance();
             dev_proxy = new DeviceProxy(device_name);
-            if(alias_name.empty() == false && dev_proxy != nullptr)
+            if(!alias_name.empty() && dev_proxy != nullptr)
             {
                 device_name = dev_proxy->dev_name();
             }
-            if(ui->in_server() == true)
+            if(ui->in_server())
             {
                 db_attr = new DbAttribute(attr_name, device_name, Tango::Util::instance()->get_database());
             }
@@ -107,7 +107,7 @@ void AttributeProxy::real_constructor(std::string &name)
     }
     else
     {
-        db_attr = NULL;
+        db_attr = nullptr;
 
         std::string::size_type stop;
         stop = name.rfind(DEVICE_SEP);
@@ -141,7 +141,7 @@ void AttributeProxy::real_constructor(std::string &name)
             TangoSys_OMemStream desc;
             desc << "Attribute " << attr_name << " is not supported by device " << device_name << std::ends;
 
-            TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept, API_UnsupportedAttribute, desc.str());
+            TANGO_THROW_DETAILED_EXCEPTION(ApiWrongNameExcept, API_UnsupportedAttribute, desc.str());
         }
     }
 }
@@ -176,12 +176,12 @@ void AttributeProxy::ctor_from_dp(const DeviceProxy *dev_ptr, const std::string
 
     device_name = dev_proxy->device_name;
 
-    if(dbase_used == true)
+    if(dbase_used)
     {
-        if(from_env_var == true)
+        if(from_env_var)
         {
             ApiUtil *ui = ApiUtil::instance();
-            if(ui->in_server() == true)
+            if(ui->in_server())
             {
                 db_attr = new DbAttribute(attr_name, device_name, Tango::Util::instance()->get_database());
             }
@@ -220,7 +220,7 @@ void AttributeProxy::ctor_from_dp(const DeviceProxy *dev_ptr, const std::string
             TangoSys_OMemStream desc;
             desc << "Attribute " << attr_name << " is not supported by device " << device_name << std::ends;
 
-            TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept, API_UnsupportedAttribute, desc.str());
+            TANGO_THROW_DETAILED_EXCEPTION(ApiWrongNameExcept, API_UnsupportedAttribute, desc.str());
         }
     }
 }
@@ -266,12 +266,12 @@ AttributeProxy::AttributeProxy(const AttributeProxy &prev) :
     device_name = prev.device_name;
     alias_name = prev.alias_name;
 
-    if(dbase_used == true)
+    if(dbase_used)
     {
-        if(from_env_var == true)
+        if(from_env_var)
         {
             ApiUtil *ui = ApiUtil::instance();
-            if(ui->in_server() == true)
+            if(ui->in_server())
             {
                 db_attr = new DbAttribute(attr_name, device_name, Tango::Util::instance()->get_database());
                 dev_proxy = new DeviceProxy(device_name);
@@ -291,9 +291,9 @@ AttributeProxy::AttributeProxy(const AttributeProxy &prev) :
         }
     }
 
-    if(prev.ext.get() != NULL)
+    if(prev.ext != nullptr)
     {
-        ext.reset(new AttributeProxyExt(prev.get_user_defined_name()));
+        ext = std::make_unique<AttributeProxyExt>(prev.get_user_defined_name());
     }
 }
 
@@ -311,7 +311,7 @@ AttributeProxy &AttributeProxy::operator=(const AttributeProxy &rval)
         // First Connection call members
         //
 
-        if(dbase_used == true)
+        if(dbase_used)
         {
             delete db_attr;
         }
@@ -332,12 +332,12 @@ AttributeProxy &AttributeProxy::operator=(const AttributeProxy &rval)
         device_name = rval.device_name;
         alias_name = rval.alias_name;
 
-        if(dbase_used == true)
+        if(dbase_used)
         {
-            if(from_env_var == true)
+            if(from_env_var)
             {
                 ApiUtil *ui = ApiUtil::instance();
-                if(ui->in_server() == true)
+                if(ui->in_server())
                 {
                     db_attr = new DbAttribute(attr_name, device_name, Tango::Util::instance()->get_database());
                     dev_proxy = new DeviceProxy(device_name);
@@ -357,9 +357,9 @@ AttributeProxy &AttributeProxy::operator=(const AttributeProxy &rval)
             }
         }
 
-        if(rval.ext.get() != NULL)
+        if(rval.ext != nullptr)
         {
-            ext.reset(new AttributeProxyExt(rval.get_user_defined_name()));
+            ext = std::make_unique<AttributeProxyExt>(rval.get_user_defined_name());
         }
         else
         {
@@ -427,7 +427,7 @@ void AttributeProxy::parse_name(std::string &full_name)
             TangoSys_OMemStream desc;
             desc << protocol;
             desc << " protocol is an unsupported protocol" << std::ends;
-            TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept, API_UnsupportedProtocol, desc.str());
+            TANGO_THROW_DETAILED_EXCEPTION(ApiWrongNameExcept, API_UnsupportedProtocol, desc.str());
         }
     }
 
@@ -457,7 +457,7 @@ void AttributeProxy::parse_name(std::string &full_name)
             TangoSys_OMemStream desc;
             desc << mod;
             desc << " modifier is an unsupported db modifier" << std::ends;
-            TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept, API_UnsupportedDBaseModifier, desc.str());
+            TANGO_THROW_DETAILED_EXCEPTION(ApiWrongNameExcept, API_UnsupportedDBaseModifier, desc.str());
         }
     }
     else
@@ -466,7 +466,7 @@ void AttributeProxy::parse_name(std::string &full_name)
         dbase_used = true;
     }
 
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         //
         // Extract host name and port number
@@ -475,7 +475,7 @@ void AttributeProxy::parse_name(std::string &full_name)
         pos = name_wo_db_mod.find(HOST_SEP);
         if(pos == std::string::npos)
         {
-            TANGO_THROW_API_EXCEPTION(
+            TANGO_THROW_DETAILED_EXCEPTION(
                 ApiWrongNameExcept, API_WrongAttributeNameSyntax, "Host and port not correctly defined in device name");
         }
 
@@ -483,7 +483,7 @@ void AttributeProxy::parse_name(std::string &full_name)
         std::string::size_type tmp = name_wo_db_mod.find(PORT_SEP);
         if(tmp == std::string::npos)
         {
-            TANGO_THROW_API_EXCEPTION(
+            TANGO_THROW_DETAILED_EXCEPTION(
                 ApiWrongNameExcept, API_WrongAttributeNameSyntax, "Host and port not correctly defined in device name");
         }
         port = name_wo_db_mod.substr(pos + 1, tmp - pos - 1);
@@ -552,19 +552,21 @@ void AttributeProxy::parse_name(std::string &full_name)
         {
             if(pos == 0)
             {
-                TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept,
-                                          API_WrongAttributeNameSyntax,
-                                          "Attribute name must have four fields separated by /'s or no /'s at all if "
-                                          "it is an alias (e.g. my/device/name/an_attr or myalias)");
+                TANGO_THROW_DETAILED_EXCEPTION(
+                    ApiWrongNameExcept,
+                    API_WrongAttributeNameSyntax,
+                    "Attribute name must have four fields separated by /'s or no /'s at all if "
+                    "it is an alias (e.g. my/device/name/an_attr or myalias)");
             }
             n_sep++;
             device_name_tmp = device_name_tmp.substr(pos + 1);
             if(device_name_tmp.size() == 0)
             {
-                TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept,
-                                          API_WrongAttributeNameSyntax,
-                                          "Attribute name must have four fields separated by /'s or no /'s at all if "
-                                          "it is an alias (e.g. my/device/name/an_attr or myalias)");
+                TANGO_THROW_DETAILED_EXCEPTION(
+                    ApiWrongNameExcept,
+                    API_WrongAttributeNameSyntax,
+                    "Attribute name must have four fields separated by /'s or no /'s at all if "
+                    "it is an alias (e.g. my/device/name/an_attr or myalias)");
             }
             device_name_end_pos += pos + 1;
         }
@@ -572,10 +574,11 @@ void AttributeProxy::parse_name(std::string &full_name)
 
     if((n_sep > 1) && (n_sep != 3))
     {
-        TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept,
-                                  API_WrongAttributeNameSyntax,
-                                  "Attribute name must have four fields separated by /'s or no /'s at all if it is an "
-                                  "alias (e.g. my/device/name/an_attr or myalias)");
+        TANGO_THROW_DETAILED_EXCEPTION(
+            ApiWrongNameExcept,
+            API_WrongAttributeNameSyntax,
+            "Attribute name must have four fields separated by /'s or no /'s at all if it is an "
+            "alias (e.g. my/device/name/an_attr or myalias)");
     }
 
     //
@@ -585,11 +588,11 @@ void AttributeProxy::parse_name(std::string &full_name)
 
     if(n_sep == 0)
     {
-        if(dbase_used == false)
+        if(!dbase_used)
         {
-            TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept,
-                                      API_WrongAttributeNameSyntax,
-                                      "Attribute alias is not supported when not using database");
+            TANGO_THROW_DETAILED_EXCEPTION(ApiWrongNameExcept,
+                                           API_WrongAttributeNameSyntax,
+                                           "Attribute alias is not supported when not using database");
         }
 
         //
@@ -599,14 +602,14 @@ void AttributeProxy::parse_name(std::string &full_name)
         pos = device_name.find(HOST_SEP);
         if(pos != std::string::npos)
         {
-            TANGO_THROW_API_EXCEPTION(
+            TANGO_THROW_DETAILED_EXCEPTION(
                 ApiWrongNameExcept, API_WrongAttributeNameSyntax, "Wrong alias name (: not allowed in alias name)");
         }
 
         pos = device_name.find(RES_SEP);
         if(pos != std::string::npos)
         {
-            TANGO_THROW_API_EXCEPTION(
+            TANGO_THROW_DETAILED_EXCEPTION(
                 ApiWrongNameExcept, API_WrongAttributeNameSyntax, "Wrong alias name (-> not allowed in alias name)");
         }
 
@@ -616,9 +619,9 @@ void AttributeProxy::parse_name(std::string &full_name)
 
         ApiUtil *ui = ApiUtil::instance();
         std::string db_attr_name;
-        if(from_env_var == true)
+        if(from_env_var)
         {
-            if(ui->in_server() == true)
+            if(ui->in_server())
             {
                 try
                 {
@@ -630,7 +633,7 @@ void AttributeProxy::parse_name(std::string &full_name)
                     {
                         TangoSys_OMemStream desc;
                         desc << "Can't connect to attribute with alias " << device_name << std::ends;
-                        TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, dfe, API_AliasNotDefined, desc.str());
+                        TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, dfe, API_AliasNotDefined, desc.str());
                     }
                     else
                     {
@@ -651,7 +654,7 @@ void AttributeProxy::parse_name(std::string &full_name)
                     {
                         TangoSys_OMemStream desc;
                         desc << "Can't connect to attribute with alias " << device_name << std::ends;
-                        TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, dfe, API_AliasNotDefined, desc.str());
+                        TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, dfe, API_AliasNotDefined, desc.str());
                     }
                     else
                     {
@@ -673,7 +676,7 @@ void AttributeProxy::parse_name(std::string &full_name)
                 {
                     TangoSys_OMemStream desc;
                     desc << "Can't connect to attribute with alias " << device_name << std::ends;
-                    TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, dfe, API_AliasNotDefined, desc.str());
+                    TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, dfe, API_AliasNotDefined, desc.str());
                 }
                 else
                 {
@@ -700,7 +703,7 @@ void AttributeProxy::parse_name(std::string &full_name)
 
         if(n_sep != 3)
         {
-            TANGO_THROW_API_EXCEPTION(
+            TANGO_THROW_DETAILED_EXCEPTION(
                 ApiWrongNameExcept,
                 API_WrongAttributeNameSyntax,
                 "Attribute name must have four fields separated by /'s (check the alias entry in the database) ");
@@ -727,12 +730,12 @@ void AttributeProxy::parse_name(std::string &full_name)
                 // but the no dbase option was used. This is an error.
                 // We can't have alias without db
                 //
-                TANGO_THROW_API_EXCEPTION(ApiWrongNameExcept,
-                                          API_WrongAttributeNameSyntax,
-                                          "Can't use device or attribute alias without database");
+                TANGO_THROW_DETAILED_EXCEPTION(ApiWrongNameExcept,
+                                               API_WrongAttributeNameSyntax,
+                                               "Can't use device or attribute alias without database");
             }
 
-            if(from_env_var == false)
+            if(!from_env_var)
             {
                 pos = name_wo_db_mod.rfind(DEVICE_SEP);
                 device_name = name_wo_db_mod.substr(0, pos);
@@ -762,7 +765,7 @@ void AttributeProxy::parse_name(std::string &full_name)
 
 AttributeProxy::~AttributeProxy()
 {
-    if(dbase_used == true)
+    if(dbase_used)
     {
         delete db_attr;
     }
@@ -834,14 +837,14 @@ bool AttributeProxy::get_transparency_reconnection()
 
 void AttributeProxy::get_property(const std::string &property_name, DbData &user_data)
 {
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         TangoSys_OMemStream desc;
         desc << "Method not available for attribute belonging to ";
         desc << device_name;
         desc << " which is a non database device";
 
-        TANGO_THROW_API_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
     }
     else
     {
@@ -872,8 +875,6 @@ void AttributeProxy::get_property(const std::string &property_name, DbData &user
             user_data.push_back(no_data);
         }
     }
-
-    return;
 }
 
 //-----------------------------------------------------------------------------
@@ -884,14 +885,14 @@ void AttributeProxy::get_property(const std::string &property_name, DbData &user
 
 void AttributeProxy::get_property(const std::vector<std::string> &property_names, DbData &user_data)
 {
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         TangoSys_OMemStream desc;
         desc << "Method not available for attribute belonging to device ";
         desc << device_name;
         desc << " which is a non database device";
 
-        TANGO_THROW_API_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
     }
     else
     {
@@ -925,8 +926,6 @@ void AttributeProxy::get_property(const std::vector<std::string> &property_names
             }
         }
     }
-
-    return;
 }
 
 //-----------------------------------------------------------------------------
@@ -937,14 +936,14 @@ void AttributeProxy::get_property(const std::vector<std::string> &property_names
 
 void AttributeProxy::get_property(DbData &user_data)
 {
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         TangoSys_OMemStream desc;
         desc << "Method not available for attribute belonging to device ";
         desc << device_name;
         desc << " which is a non database device";
 
-        TANGO_THROW_API_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
     }
     else
     {
@@ -974,8 +973,6 @@ void AttributeProxy::get_property(DbData &user_data)
             }
         }
     }
-
-    return;
 }
 
 //-----------------------------------------------------------------------------
@@ -986,14 +983,14 @@ void AttributeProxy::get_property(DbData &user_data)
 
 void AttributeProxy::put_property(const DbData &user_data)
 {
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         TangoSys_OMemStream desc;
         desc << "Method not available for attribute belonging to device ";
         desc << device_name;
         desc << " which is a non database device";
 
-        TANGO_THROW_API_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
     }
     else
     {
@@ -1009,8 +1006,6 @@ void AttributeProxy::put_property(const DbData &user_data)
 
         db_attr->put_property(db_data);
     }
-
-    return;
 }
 
 //-----------------------------------------------------------------------------
@@ -1021,14 +1016,14 @@ void AttributeProxy::put_property(const DbData &user_data)
 
 void AttributeProxy::delete_property(const std::string &property_name)
 {
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         TangoSys_OMemStream desc;
         desc << "Method not available for attribute belonging to device ";
         desc << device_name;
         desc << " which is a non database device";
 
-        TANGO_THROW_API_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
     }
     else
     {
@@ -1036,12 +1031,10 @@ void AttributeProxy::delete_property(const std::string &property_name)
 
         DbDatum att(attr_name);
         db_data.push_back(att);
-        db_data.push_back(DbDatum(property_name));
+        db_data.emplace_back(property_name);
 
         db_attr->delete_property(db_data);
     }
-
-    return;
 }
 
 //-----------------------------------------------------------------------------
@@ -1052,14 +1045,14 @@ void AttributeProxy::delete_property(const std::string &property_name)
 
 void AttributeProxy::delete_property(const std::vector<std::string> &property_names)
 {
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         TangoSys_OMemStream desc;
         desc << "Method not available for attribute belonging to device ";
         desc << device_name;
         desc << " which is a non database device";
 
-        TANGO_THROW_API_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
     }
     else
     {
@@ -1069,13 +1062,11 @@ void AttributeProxy::delete_property(const std::vector<std::string> &property_na
         db_data.push_back(att);
         for(unsigned int i = 0; i < property_names.size(); i++)
         {
-            db_data.push_back(DbDatum(property_names[i]));
+            db_data.emplace_back(property_names[i]);
         }
 
         db_attr->delete_property(db_data);
     }
-
-    return;
 }
 
 //-----------------------------------------------------------------------------
@@ -1086,14 +1077,14 @@ void AttributeProxy::delete_property(const std::vector<std::string> &property_na
 
 void AttributeProxy::delete_property(const DbData &user_data)
 {
-    if(dbase_used == false)
+    if(!dbase_used)
     {
         TangoSys_OMemStream desc;
         desc << "Method not available for attribute belonging to device ";
         desc << device_name;
         desc << " which is a non database device";
 
-        TANGO_THROW_API_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonDbExcept, API_NonDatabaseDevice, desc.str());
     }
     else
     {
@@ -1108,8 +1099,6 @@ void AttributeProxy::delete_property(const DbData &user_data)
 
         db_attr->delete_property(db_data);
     }
-
-    return;
 }
 
 //-----------------------------------------------------------------------------
@@ -1142,7 +1131,7 @@ void AttributeProxy::set_config(AttributeInfo &dev_attr_info)
     {
         TangoSys_OMemStream desc;
         desc << "Failed to execute set_attribute_config on device " << device_name << std::ends;
-        TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
     }
 }
 
@@ -1159,7 +1148,7 @@ void AttributeProxy::set_config(AttributeInfoEx &dev_attr_info)
     {
         TangoSys_OMemStream desc;
         desc << "Failed to execute set_attribute_config on device " << device_name << std::ends;
-        TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
     }
 }
 
@@ -1289,7 +1278,7 @@ int AttributeProxy::subscribe_event(EventType event,
                                     bool stateless)
 {
     ApiUtil *api_ptr = ApiUtil::instance();
-    if(api_ptr->get_zmq_event_consumer() == NULL)
+    if(api_ptr->get_zmq_event_consumer() == nullptr)
     {
         api_ptr->create_zmq_event_consumer();
     }
@@ -1309,7 +1298,7 @@ int AttributeProxy::subscribe_event(EventType event,
         std::string reason(e.errors[0].reason.in());
         if(reason == API_CommandNotFound)
         {
-            if(ApiUtil::instance()->get_notifd_event_consumer() == NULL)
+            if(ApiUtil::instance()->get_notifd_event_consumer() == nullptr)
             {
                 ApiUtil::instance()->create_notifd_event_consumer();
             }
@@ -1346,7 +1335,7 @@ int AttributeProxy::subscribe_event(EventType event,
                                     bool stateless)
 {
     ApiUtil *api_ptr = ApiUtil::instance();
-    if(api_ptr->get_zmq_event_consumer() == NULL)
+    if(api_ptr->get_zmq_event_consumer() == nullptr)
     {
         api_ptr->create_zmq_event_consumer();
     }
@@ -1362,7 +1351,7 @@ int AttributeProxy::subscribe_event(EventType event,
         std::string reason(e.errors[0].reason.in());
         if(reason == API_CommandNotFound)
         {
-            if(api_ptr->get_notifd_event_consumer() == NULL)
+            if(api_ptr->get_notifd_event_consumer() == nullptr)
             {
                 api_ptr->create_notifd_event_consumer();
             }
