@@ -5,11 +5,9 @@
 #include <iostream>
 #include <exception>
 
-namespace Tango
+namespace Tango::detail
 {
-namespace detail
-{
-void assertion_failure(const char *file, int line, const char *func, const char *expr)
+void assertion_failure(const char *file, int line, const char *func, const char *msg)
 {
     // When called from the TANGO_ASSERT macro these nullptr checks never
     // fire, however, on the off chance that someone calls this function in a
@@ -26,9 +24,9 @@ void assertion_failure(const char *file, int line, const char *func, const char
         func = "unknown";
     }
 
-    if(expr == nullptr)
+    if(msg == nullptr)
     {
-        expr = "";
+        msg = "";
     }
 
     const char *basename = ::Tango::logging_detail::basename(file);
@@ -37,13 +35,12 @@ void assertion_failure(const char *file, int line, const char *func, const char
     {
         using SourceLocation = log4tango::LoggerStream::SourceLocation;
 
-        API_LOGGER->fatal_stream() << log4tango::_begin_log << SourceLocation{basename, line} << func << ": Assertion '"
-                                   << expr << "' failed" << log4tango::_end_log;
+        API_LOGGER->fatal_stream() << log4tango::_begin_log << SourceLocation{basename, line} << func << ": " << msg
+                                   << log4tango::_end_log;
     }
 
-    std::cerr << basename << ":" << line << " " << func << ": Assertion '" << expr << "' failed\n";
+    std::cerr << basename << ":" << line << " " << func << ": " << msg << "\n";
 
     std::terminate();
 }
-} // namespace detail
-} // namespace Tango
+} // namespace Tango::detail
